.. expect: found an unbalanced inline literal markup. (unbalanced-inline-literals-delimiters)
.. expect: found an unbalanced inline literal markup. (unbalanced-inline-literals-delimiters)

That space make the intended inline literal not being one: `` __repr__``.
